@@ -5,12 +5,22 @@ from .model.snowflake import Snowflake
 class CacheContainer:
     def __init__(self, default_expiration_time=None, **max_sizes):
         self.default_expiration_time = default_expiration_time
-        self.__cache_dict: typing.Dict[str, typing.Union[dict, CacheStorage]] = {"guild_cache": {}}
+        self.__cache_dict: typing.Dict[str, typing.Union[dict, CacheStorage]] = {
+            "guild_cache": {}
+        }
         self.max_sizes = max_sizes
 
-    def get(self, snowflake_id: typing.Union[str, int, Snowflake], storage_type: str = None, *, ignore_expiration=True):
+    def get(
+        self,
+        snowflake_id: typing.Union[str, int, Snowflake],
+        storage_type: str = None,
+        *,
+        ignore_expiration=True
+    ):
         if storage_type:
-            return self.get_storage(storage_type).get(snowflake_id, ignore_expiration=ignore_expiration)
+            return self.get_storage(storage_type).get(
+                snowflake_id, ignore_expiration=ignore_expiration
+            )
         for x in self.__cache_dict.values():
             if isinstance(x, dict):
                 continue
@@ -22,23 +32,41 @@ class CacheContainer:
         if storage_type == "guild_cache":
             return self.__cache_dict["guild_cache"]
         if storage_type not in self.__cache_dict:
-            self.__cache_dict[storage_type] = CacheStorage(max_size=self.max_sizes.get(storage_type, 0), root_remove=self.remove, cache_type=storage_type)
+            self.__cache_dict[storage_type] = CacheStorage(
+                max_size=self.max_sizes.get(storage_type, 0),
+                root_remove=self.remove,
+                cache_type=storage_type,
+            )
         return self.__cache_dict.get(storage_type)
 
     def get_guild_container(self, guild_id: typing.Union[str, int, Snowflake]):
         guild_caches = self.get_storage("guild_cache")
         guild_id = Snowflake.ensure_snowflake(guild_id)
         if guild_id not in guild_caches:
-            guild_caches[guild_id] = GuildCacheContainer(default_expiration_time=self.default_expiration_time)
+            guild_caches[guild_id] = GuildCacheContainer(
+                default_expiration_time=self.default_expiration_time
+            )
         return guild_caches[guild_id]
 
-    def add(self, snowflake_id: typing.Union[str, int, Snowflake], obj_type: str, obj, expire_at=None):
+    def add(
+        self,
+        snowflake_id: typing.Union[str, int, Snowflake],
+        obj_type: str,
+        obj,
+        expire_at=None,
+    ):
         if not expire_at:
             expire_at = self.default_expiration_time
 
         if obj_type not in self.__cache_dict:
-            self.__cache_dict[obj_type] = CacheStorage(max_size=self.max_sizes.get(obj_type, 0), root_remove=self.remove, cache_type=obj_type)
-        self.__cache_dict[obj_type].add(Snowflake.ensure_snowflake(snowflake_id), obj, expire_at)
+            self.__cache_dict[obj_type] = CacheStorage(
+                max_size=self.max_sizes.get(obj_type, 0),
+                root_remove=self.remove,
+                cache_type=obj_type,
+            )
+        self.__cache_dict[obj_type].add(
+            Snowflake.ensure_snowflake(snowflake_id), obj, expire_at
+        )
 
     def remove(self, snowflake_id: typing.Union[str, int, Snowflake], obj_type: str):
         if obj_type in self.__cache_dict:
@@ -92,7 +120,9 @@ class CacheStorage:
         for x in self.__cache_dict.values():
             yield x
 
-    def get(self, snowflake_id: typing.Union[str, int, Snowflake], *, ignore_expiration=True):
+    def get(
+        self, snowflake_id: typing.Union[str, int, Snowflake], *, ignore_expiration=True
+    ):
         res = self.__cache_dict.get(Snowflake.ensure_snowflake(snowflake_id))
         if res:  # TODO: add expiration time check
             return res["value"]
