@@ -8,19 +8,28 @@ from ...base.model import TypeBase
 
 class ApplicationCommand:
     TYPING = typing.Union[int, str, Snowflake, "ApplicationCommand"]
-    RESPONSE = typing.Union["ApplicationCommand", typing.Awaitable["ApplicationCommand"]]
-    RESPONSE_AS_LIST = typing.Union[typing.List["ApplicationCommand"], typing.Awaitable[typing.List["ApplicationCommand"]]]
+    RESPONSE = typing.Union[
+        "ApplicationCommand", typing.Awaitable["ApplicationCommand"]
+    ]
+    RESPONSE_AS_LIST = typing.Union[
+        typing.List["ApplicationCommand"],
+        typing.Awaitable[typing.List["ApplicationCommand"]],
+    ]
 
-    def __init__(self,
-                 name: str,
-                 description: str,
-                 command_type: typing.Optional[typing.Union[int, "ApplicationCommandTypes"]] = 1,
-                 options: typing.Optional[typing.List["ApplicationCommandOption"]] = None,
-                 default_permission: typing.Optional[bool] = True,
-                 **resp):
+    def __init__(
+        self,
+        name: str,
+        description: str,
+        command_type: typing.Optional[typing.Union[int, "ApplicationCommandTypes"]] = 1,
+        options: typing.Optional[typing.List["ApplicationCommandOption"]] = None,
+        default_permission: typing.Optional[bool] = True,
+        **resp
+    ):
         self.id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("id"))
         self.type: ApplicationCommandTypes = ApplicationCommandTypes(int(command_type))
-        self.application_id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("application_id"))
+        self.application_id: typing.Optional[Snowflake] = Snowflake.optional(
+            resp.get("application_id")
+        )
         self.name: str = name
         self.description: str = description
         self.options: typing.List[ApplicationCommandOption] = options or []
@@ -32,7 +41,13 @@ class ApplicationCommand:
             return int(self.id)
 
     def to_dict(self) -> dict:
-        resp = {"name": self.name, "description": self.description, "options": [x.to_dict() for x in self.options], "default_permission": self.default_permission, "type": int(self.type)}
+        resp = {
+            "name": self.name,
+            "description": self.description,
+            "options": [x.to_dict() for x in self.options],
+            "default_permission": self.default_permission,
+            "type": int(self.type),
+        }
         if self.__command_creation:
             return resp
         resp["id"] = str(self.id)
@@ -41,7 +56,9 @@ class ApplicationCommand:
 
     @classmethod
     def create(cls, resp):
-        resp["options"] = [ApplicationCommandOption.create(x) for x in resp.pop("options", [])]
+        resp["options"] = [
+            ApplicationCommandOption.create(x) for x in resp.pop("options", [])
+        ]
         resp["command_type"] = resp.pop("type", 1)
         return cls(**resp)
 
@@ -53,28 +70,43 @@ class ApplicationCommandTypes(TypeBase):
 
 
 class ApplicationCommandOption:
-    def __init__(self,
-                 option_type: typing.Union["ApplicationCommandOptionType", int],
-                 name: str,
-                 description: str,
-                 required: typing.Optional[bool] = None,
-                 choices: typing.Optional[typing.List["ApplicationCommandOptionChoice"]] = None,
-                 autocomplete: typing.Optional[bool] = None,
-                 options: typing.Optional[typing.List["ApplicationCommandOption"]] = None,
-                 channel_types: typing.Optional[typing.List[typing.Union[int, ChannelTypes]]] = None,
-                 **kw):
-        self.type: ApplicationCommandOptionType = ApplicationCommandOptionType(int(option_type))
+    def __init__(
+        self,
+        option_type: typing.Union["ApplicationCommandOptionType", int],
+        name: str,
+        description: str,
+        required: typing.Optional[bool] = None,
+        choices: typing.Optional[typing.List["ApplicationCommandOptionChoice"]] = None,
+        autocomplete: typing.Optional[bool] = None,
+        options: typing.Optional[typing.List["ApplicationCommandOption"]] = None,
+        channel_types: typing.Optional[
+            typing.List[typing.Union[int, ChannelTypes]]
+        ] = None,
+        **kw
+    ):
+        self.type: ApplicationCommandOptionType = ApplicationCommandOptionType(
+            int(option_type)
+        )
         self.name: str = name
         self.description: str = description
         self.required: typing.Optional[bool] = required
-        self.choices: typing.Optional[typing.List[ApplicationCommandOptionChoice]] = choices
+        self.choices: typing.Optional[
+            typing.List[ApplicationCommandOptionChoice]
+        ] = choices
         self.autocomplete: typing.Optional[bool] = autocomplete
         self.options: typing.Optional[typing.List[ApplicationCommandOption]] = options
-        self.channel_types: typing.Optional[typing.List[ChannelTypes]] = \
-            [*map(lambda x: ChannelTypes(int(x)), channel_types)] if channel_types is not None else channel_types
+        self.channel_types: typing.Optional[typing.List[ChannelTypes]] = (
+            [*map(lambda x: ChannelTypes(int(x)), channel_types)]
+            if channel_types is not None
+            else channel_types
+        )
 
     def to_dict(self) -> dict:
-        ret = {"type": int(self.type), "name": self.name, "description": self.description}
+        ret = {
+            "type": int(self.type),
+            "name": self.name,
+            "description": self.description,
+        }
         if self.required is not None:
             ret["required"] = self.required
         if self.options is not None:
@@ -89,7 +121,9 @@ class ApplicationCommandOption:
 
     @classmethod
     def create(cls, resp):
-        resp["choices"] = [ApplicationCommandOptionChoice.create(x) for x in resp.get("choices", [])] or None
+        resp["choices"] = [
+            ApplicationCommandOptionChoice.create(x) for x in resp.get("choices", [])
+        ] or None
         resp["options"] = [cls.create(x) for x in resp.get("options", [])] or None
         resp["option_type"] = resp.pop("type")
         return cls(**resp)
@@ -122,28 +156,44 @@ class ApplicationCommandOptionChoice:
 
 
 class GuildApplicationCommandPermissions:
-    RESPONSE = typing.Union["GuildApplicationCommandPermissions", typing.Awaitable["GuildApplicationCommandPermissions"]]
-    RESPONSE_AS_LIST = typing.Union[typing.List["GuildApplicationCommandPermissions"], typing.Awaitable[typing.List["GuildApplicationCommandPermissions"]]]
+    RESPONSE = typing.Union[
+        "GuildApplicationCommandPermissions",
+        typing.Awaitable["GuildApplicationCommandPermissions"],
+    ]
+    RESPONSE_AS_LIST = typing.Union[
+        typing.List["GuildApplicationCommandPermissions"],
+        typing.Awaitable[typing.List["GuildApplicationCommandPermissions"]],
+    ]
 
     def __init__(self, resp: dict):
         self.id: Snowflake = Snowflake(resp["id"])
         self.application_id: Snowflake = Snowflake(resp["application_id"])
         self.guild_id: Snowflake = Snowflake(resp["guild_id"])
-        self.permissions: typing.List[ApplicationCommandPermissions] = [ApplicationCommandPermissions.create(x) for x in resp["permissions"]]
+        self.permissions: typing.List[ApplicationCommandPermissions] = [
+            ApplicationCommandPermissions.create(x) for x in resp["permissions"]
+        ]
 
 
 class ApplicationCommandPermissions:
-    def __init__(self,
-                 target: typing.Union[Role.TYPING, User.TYPING],
-                 permission_type: typing.Union[int, "ApplicationCommandPermissionType"],
-                 permission: bool,
-                 **kw):
+    def __init__(
+        self,
+        target: typing.Union[Role.TYPING, User.TYPING],
+        permission_type: typing.Union[int, "ApplicationCommandPermissionType"],
+        permission: bool,
+        **kw
+    ):
         self.id: typing.Optional[Snowflake] = Snowflake.ensure_snowflake(int(target))
-        self.type: ApplicationCommandPermissionType = ApplicationCommandPermissionType(int(permission_type))
+        self.type: ApplicationCommandPermissionType = ApplicationCommandPermissionType(
+            int(permission_type)
+        )
         self.permission: bool = permission
 
     def to_dict(self) -> dict:
-        return {"id": str(self.id), "type": int(self.type), "permission": self.permission}
+        return {
+            "id": str(self.id),
+            "type": int(self.type),
+            "permission": self.permission,
+        }
 
     @classmethod
     def create(cls, resp):
@@ -160,7 +210,11 @@ class ApplicationCommandPermissionType(TypeBase):
 class ApplicationCommandInteractionDataOption:
     def __init__(self, resp: dict):
         self.name: str = resp["name"]
-        self.type: ApplicationCommandOptionType = ApplicationCommandOptionType(resp["type"])
+        self.type: ApplicationCommandOptionType = ApplicationCommandOptionType(
+            resp["type"]
+        )
         self.value: typing.Optional = resp.get("value")
-        self.options: typing.List[ApplicationCommandInteractionDataOption] = [ApplicationCommandInteractionDataOption(x) for x in resp.get("options", [])]
+        self.options: typing.List[ApplicationCommandInteractionDataOption] = [
+            ApplicationCommandInteractionDataOption(x) for x in resp.get("options", [])
+        ]
         self.focused: typing.Optional[bool] = resp.get("focused")
