@@ -12,7 +12,9 @@ if typing.TYPE_CHECKING:
 class StageInstance(DiscordObjectBase):
     TYPING = typing.Union[int, str, Snowflake, "StageInstance"]
     RESPONSE = typing.Union["StageInstance", typing.Awaitable["StageInstance"]]
-    RESPONSE_AS_LIST = typing.Union[typing.List["StageInstance"], typing.Awaitable[typing.List["StageInstance"]]]
+    RESPONSE_AS_LIST = typing.Union[
+        typing.List["StageInstance"], typing.Awaitable[typing.List["StageInstance"]]
+    ]
     _cache_type = "stage_instance"
 
     def __init__(self, client: "APIClient", resp: dict):
